package ninja_utils

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ninja_utils.BuildSource

Helper module to build ninja build statements.

Sourcetype t

Represents the minimal ninja build statement representation for Clerk:

  build <outputs>: <rule> [<inputs>]
    [<vars>]
Sourceval make : ?inputs:Expr.t -> ?implicit_in:Expr.t -> outputs:Expr.t -> ?implicit_out:Expr.t -> ?vars:Binding.any list -> string -> t

make ~outputs rule returns the corresponding ninja Build.t.

Sourceval format : Format.formatter -> t -> unit

format fmt build outputs in fmt the string representation of the ninja build.